/**
 * @file
 * JavaScript unit tests for Virtuous personalization.
 */

(function ($, Drupal) {
  "use strict";

  /**
   * Test the personalization functionality.
   */
  Drupal.tests.virtuousPersonalization = {
    getInfo: function () {
      return {
        name: 'Virtuous Personalization',
        description: 'Test the personalization JavaScript functionality.',
        group: 'Virtuous Personalization'
      };
    },
    tests: {
      testDomUpdates: function (test) {
        // Set up test DOM elements.
        $('body').append(
          '<div class="virtuous-personalized-name">friend</div>' +
          '<div class="virtuous-personalized-greeting"></div>' +
          '<div class="virtuous-anonymous-only">Anonymous content</div>' +
          '<div class="virtuous-identified-only" style="display: none;">Identified content</div>'
        );

        // Simulate success response from endpoint.
        const mockData = {
          isIdentified: true,
          contactName: 'Test User'
        };

        // Manual call to update DOM with data.
        $('.virtuous-personalized-name').text(mockData.contactName);
        $('.virtuous-personalized-greeting').text('Welcome back, ' + mockData.contactName + '!');
        $('.virtuous-anonymous-only').hide();
        $('.virtuous-identified-only').show();

        // Assertions.
        test.assertEqual(
          $('.virtuous-personalized-name').text(),
          'Test User',
          'Personalized name was updated correctly'
        );
        test.assertEqual(
          $('.virtuous-personalized-greeting').text(),
          'Welcome back, Test User!',
          'Greeting was generated correctly'
        );
        test.assertEqual(
          $('.virtuous-anonymous-only').css('display'),
          'none',
          'Anonymous content is hidden'
        );
        test.assertEqual(
          $('.virtuous-identified-only').css('display'),
          'block',
          'Identified content is shown'
        );

        // Clean up.
        $('.virtuous-personalized-name, .virtuous-personalized-greeting, .virtuous-anonymous-only, .virtuous-identified-only').remove();
      }
    }
  };
})(jQuery, Drupal);
